Changelog
=========

9.5.3 (2023-01-01)
------------------

- URL : Suppression du ".html" en fin d'adresse
- URL : Utilisation des liens en ".html" sans rejet 404
- URL : N'affiche plus "index" par défaut sur l'accueil
- BANNIERE : Correction d'un comportement indésirable
- MATCHS : Retrait de la numérotation
- PARTENAIRES RÉCENTS : Clarification Star et colorité
- MATCHS : Tri par ordre alphabétique dans fiche pilote
- RESPONSIVE : Taille des images dans les articles


9.5.2 (2022-12-27)
------------------

- DECKS : Correction du positionnement des pilotes


9.5.1 (2022-12-27)
------------------

- STYLE : Modification des délais de transitions


9.5.0 (2022-12-27)
------------------

- STYLE : Ajout d'une transition pour réduire les bannières de match


9.4.2 (2022-12-27)
------------------

- INDEX : Affichage des matchs via un carousel
- INDEX : Ajout d'un lien dans le carousel
- YOSHIMARU : Clarification de la colorité
- MENU : Déplacement du style dans le fichier dédié
- STYLE : Refactoring en fichier JS
- SQUELETTE : Nettoyage du code et des fichiers inutiles
- STYLE : Ajout d'un constructeur de bannière
- ANAËL : Correction de l'image
- STYLE : Correction des classes de tip
- LEOVOLD : Ajout de la fiche du deck
- MATCH 37 : Ajout de la page de match


9.4.1 (2022-12-10)
------------------

- MATCH 36 : Ajout des liens dans les pages de deck
- APPARENCE : Amélioration des encarts de matchs sur la page d'accueil


9.4.0 (2022-12-10)
------------------

- KROXA : Ajout du deck
- CECILY-WERNOG : Ajout du deck
- MATCH 35 : Ajout du match
- RESPONSIVE : Correction du block SLD Universe Beyond
- GHYRSON : Ajout du deck
- NIV-MIZZET : Ajotu de la decklsit de NicolasP
- PILOTES : Ajout des liens et réordonnancement
- MATCH 36 : Ajout du match


9.3.0 (2022-11-27)
------------------

- Changement de pp pour nicolasp
- Ajout d'un nouveau pilote : Jules « Askeladden »
- Match 34 : Grist vs Raffine


9.2.1 (2022-11-14)
------------------

- Correction du contrôle de légalité


9.2.0 (2022-11-13)
------------------

- Ajout de la liste des généraux légaux


9.1.0 (2022-11-11)
------------------

- Retrait des lignes vides dans la génération
- Ajout de la mention "Sideboard" pour intégration Cockatrice
- Ajout d'un nouveau pilote : Nicolas « NicolasP »
- Création de la page du match #33
- Modification de l'affichage des decks dans les pages des pilotes
- Ajout de l'affichage des derniers matchs sur la page d'accueil
- Menu déroulant déclenché au passage de la souris
- Ajout d'un symbole pour expliciter le menu déroulant imbriqué


9.0.1 (2022-11-10)
------------------

- Correction du lien de génération


9.0.0 (2022-11-10)
------------------

- Ajout de la génération txt des decklists
- Ajout de la génération des boutons vers les listes
- Ajout de l'option "outline" pour les boutons
- Correction des templates de deck


8.3.1 (2022-11-02)
------------------

- GRENZO - Ajout d'un séparateur manquant
- INDEX - Nettoyage du code en trop de la page
- JURI - Ajout de la decktech


8.3.0 (2022-10-30)
------------------

- Correction de l'affichage des cartes bannies
- MODULE - Réduction du nombre d'instructions
- PILOTE - Ajout d'Alexandre « OneSauk »
- CONTEXTE - Ajout des symboles de mana
- MATCH 32 - Ajout de la page du match
- MATCH 32 - Ajout des decks
- MATCH 32 - MAJ des fiches pilotes
- GRENZO - Ajout du primer de Ejell de février 2021


8.2.3 (2022-10-09)
------------------

- Correction de la miniature de Tiamat
- Ajout des matches 31 à 40
- Ajout logo Github dans le footer
- Accessibility - Alt text de la bannière
- Accessibility - ID identiques dans le menu
- Accessibility - Liens sur logos trop petits
- Accessibility - First Painful Content géré en lazy loading
- SEO - Links are not crawlable
- Correction des espaces insécables pour les noms de cartes
- Ajout d'un système de sous-pages pour les archétypes
- Ajout d'un système de sous-pages pour les matchs


8.2.2 (2022-10-08)
------------------

- Correction da l'analyse du match 31


8.2.1 (2022-10-08)
------------------

- Correction du responsive de l'affichage des cartes
- Correction de l'affichage des cartes renommées après SLD


8.2.0 (2022-10-08)
------------------

- Refonte de l'affichage des cartes
- Match 31 : Raffine vs Soul of Windgrace


8.1.0 (2022-09-30)
------------------

- Match 30 : Gut vs Yoshimaru
- Correction du lien sur la page de Livio-Prava
- Ajout de la deck tech de Gitrog


8.0.0 (2022-09-29)
------------------

- Mise à jour de la définition de Midrange
- Ajout analyse 21. Aminatou vs Beamtown Bullies
- Ajout analyse 22. Raffine vs Tivit
- Image "firstprint" de chaque carte systématique
- Amélioration de la génération des liens Scryfall
- Ajout du lazy loading
- Fix images Tiamat
- Colorisation des noms de cartes et ajout d'espace insécable
- Correction grammaire analyse 22. Raffine vs Tivit
- Nouvelle catégorie : articles
- Fix définition Midrange
- Article sur la roue des archétypes
- Lien vers la roue dans match 22


7.2.0 (2022-09-24)
------------------

- Adding isort to project
- Changement de la miniature pour le deck Wilson + Background
- Match 29 : Erinis vs Raff
- Ajout deck tech Niv Mizzet Reborn


7.1.0 (2022-08-17)
------------------

- Refonte de l'apparence: Ajout de tag dans la navigation
- Ajout des pages dans le contexte de base
- Refonte de l'apparence: Réfection du menu
- Backend: Simplification des calls au helper
- Ajout des logos via Font Awesome Brand
- Ajout des img_crop dans le contexte de base
- Refonte de l'apparence: Decks index par type
- Ajout des définitions des macrotypes dans l'index
- Refonte de l'apparence: Match index par dizaine
- Refonte de l'apparence: Contexte passé au template 404
- Refonte de l'apparence: Lien réseaux sociaux en pied
- Backend: Ajout d'une fonction pour les infos des pilotes
- Refonte de l'apparence: Pilotes index par qté de matchs


6.29.6 (2022-08-17)
-------------------

- Small fix: change name for more consistency
- Fix responsive issue in matchs pages


6.29.5 (2022-08-13)
-------------------

- Small fix: typo
- Small fix: calculated names
- Small fix: move block around
- Small fix: b&r date in index


6.29.4 (2022-08-11)
-------------------

- Fixing OG image and description


6.29.3 (2022-08-11)
-------------------

- Fix Menu responsive
- Ajout lien vers repo Github
- Tous les tab sont 4 espaces


6.29.2 (2022-08-11)
-------------------

- Fix « Deck Tech »


6.29.1 (2022-08-11)
-------------------

- Deck Tech de Raffine


6.29.0 (2022-08-09)
-------------------

- Rollback versioning


6.28.0.09.08.2022 (2022-08-09)
------------------------------

- Match 28 oublié dans la liste des matchs
- Reprise du versioning (MINOR = 28 car il s'agit du 28e match)


6.0.2 (2022-08-09)
------------------

- Correction pour tests
- Correction du fichier ReadMe


6.0.1 (2022-08-09)
------------------

- Ajout de la version du site en bas de page
- Modification de la mise en page pour les généraux bannis
- Match 27 : Jori En vs Maelstrom Wanderer
- Match 28 : Azusa vs Elmar-Hargilde


6.0.0 (2022-08-08)
------------------

- Changing website content
- Removing i10n support


5.2.1 (2021-12-06)
------------------

- Modification d'apparence de la page MDC
- Correction de la génération de la decklist
- Tri alphabétique des cartes dans la decklist


5.1.4 (2021-12-06)
------------------

- Tools devient Outils
- Ajout de la section Outils au header
- Correction d'une erreur de dépendances
- Amélioration du validateur Modern Duel Commander
- Ajout du Modern Duel Commander à la page Outils
- Présentation du Modern Duel Commander


5.1.3 (2021-11-11)
------------------

- Small fixes


5.1.2 (2021-09-30)
------------------

- Correction de l'affichage des decklists sur mobile
- Mise à jour du sitemap


5.1.1 (2021-09-30)
------------------

- Correction dans les annonces de banlist
- Correction des balises meta pour EN
- Modification de l'affichage des decks sur mobile !définitif


5.1.0 (2021-09-29)
------------------

- Article "Les Spot Removal" traduit
- Article "Les Mass Removal" traduit
- Article "Les Piocheurs" traduit
- Ajout d'une section pour les decks bannis
- Ajout d'une review de Niv-Mizzet
- Modification de la navigation
- Modification de l'affichage des decks sur mobile !temporaire
- Préparation de l'évolution de l'affichage sur mobile


5.0.3 (2021-09-12)
------------------

- Section Archétypes complètement traduite
- Article "Classifier un deck" traduit
- Article "Construire un deck" traduit
- Section Articles complètement traduite


5.0.2 (2021-08-26)
------------------

- Refactoring "Classifier un deck"
- [PARTIEL] Traduction du site en anglais


5.0.1 (2021-08-26)
------------------

- Ajout d'une vidéo de decktech de Isamaru
- Correction d'un problème d'affichage


5.0.0 (2021-08-15)
------------------

- Amélioration de la dénomination des pages
- Utilisation des checks de black et de flake8
- Ajout de tests
- Correction selon retours des tests unitaires


4.1.0 (2021-08-11)
------------------

- Amélioration des métadonnées
- Correction des blocs de traduction concernant les cartes bannies
- Intégration moxfield pour les decklists


4.0.3 (2021-08-10)
------------------

- [BETA only] Correction de l'intégration


4.0.2 (2021-08-10)
------------------

- Ajout d'une analyse de Arcades
- Retrait de l'article sur la complexité de Magic
- Retrait de l'article sur le mélange
- Correction du sitemap
- Update de la liste de Adeliz
- [BETA only] Ajout d'un embed sur octavia


4.0.1 (2021-08-06)
------------------

- Désactivation de la fonctionnalité


4.0.0 (2021-08-06)
------------------

- Ajout d'une fonctionnalité pour sauvegarder une image du site


3.6.8 (2021-08-06)
------------------

- Ajout d'une liste de Doran
- Ajout d'une liste de Hogaak
- Corrections esthétiques
- Fix génération de decks
- Update de la liste de Kess
- Update de la liste de Gitrog


3.6.7 (2021-08-06)
------------------

- Update de la liste de Kinnan
- Update de la liste d'Octavia
- Modification de l'affichage des Lands MDFC


3.6.6 (2021-07-29)
------------------

- Ajout d'une liste de Niv-Mizzet Reborn
- Ajout d'une liste de Octavia
- Correction du symbole pour les cartes bannies


3.6.5 (2021-07-28)
------------------

- Mise à jour de la liste de Adeliz
- Mise à jour de la liste de Aminatou
- Mise à jour de la liste de Golos
- Mise à jour de la liste de Winota
- Ajout d'une mention pour le ban de Gifts
- Gestion des cartes bannies


3.6.4 (2021-07-28)
------------------

- Ajout d'une liste de Arcades
- Ajout d'une liste de Galazeth
- Ajout d'une liste de Miara-Tevesh
- Mise à jour de la liste de Isamaru


3.6.3 (2021-07-28)
------------------

- Ajout d'un primer sur Cosima/Omenkeel
- Ajout d'un primer sur Minsc, Beloved Ranger
- Correction de deux typos sur Magda


3.6.2 (2021-04-14)
------------------

- Ajout de Magda dans le sitemap


3.6.1 (2021-04-13)
------------------

- Correction d'un nom de carte dans le primer de Magda


3.6.0 (2021-04-13)
------------------

- Ajout d'un primer sur Magda, Brazen Outlaw
- Correction de la navigation
- Correction de l'affichage des decklists


3.5.0 (2021-03-15)
------------------

- Amélioration de l'outil de tirage au sort : reset au remplissage du bol
- Ajout d'un primer sur Kinnan


3.4.1 (2021-02-26)
------------------

- Mise à jour du site map
- Optimisation de l'affichage
- Correction d'erreurs de saisie (Archétypes, listes et article)


3.4.0 (2021-02-25)
------------------

- Versioning fix
- Section name change
- Ajout d'un outil de tirage au sort


3.3.3 (2021-02-25)
------------------

- Correction typographie dans Grenzo


3.3.2 (2021-02-24)
------------------

- Mise à jour du site map


3.3.1 (2021-02-24)
------------------

- Correction de l'alignement d'une image dans Grenzo


3.3.0 (2021-02-24)
------------------

- Préparation de la traduction en anglais
- Proof-reading de plusieurs articles
- Ajout d'un primer sur Grenzo, Dungeon Warden


3.2.5 (2021-02-18)
------------------

- Amélioration du simulateur A+B


3.2.4 (2021-02-18)
------------------

- Déplacement des images des Ik-O-Maths
- Correction du paragraphe de présentation des Ik-O-Maths
- Correction d'un problème d'affichage sur mobile


3.2.3 (2021-02-18)
------------------

- Création d'un layout pour les futurs calculateurs
- Ajout des Ik-O-Maths
- Correction des titres d'articles


3.2.2 (2021-02-17)
------------------

- Correction du nom d'une carte dans l'article A+B
- Correction des valeurs limites pour le calcul de la série


3.2.1 (2021-02-17)
------------------

- Ajout d'un descriptif pour le simulateur A+B


3.2.0 (2021-02-17)
------------------

- Ajout d'une section non-répertoriée de simulateurs
- Ajout d'un simulateur pour l'accès a A+B


3.1.3 (2021-02-17)
------------------

- Correction d'un problème de sécurité avec les liens externes
- Amélioration de l'affichage du texte pendant le chargement des polices
- Correction du ralentissement de chargement des decklists
- Correction des packages en backend


3.1.2 (2021-02-16)
------------------

- Corrections sur Orvar
- Correction du pseudo


3.1.1 (2021-02-16)
------------------

- Correction d'un lien sur le primer d'Orvar
- Ajout du pseudo de Soullessoni


3.1.0 (2021-02-16)
------------------

- Ajout d'un article sur la complexité mathématique de Magic 1/4
- Ajout d'un article sur la complexité mathématique de Magic 2/4
- Ajout d'un primer sur Orvar, the All-Form


3.0.5 (2021-02-12)
------------------

- Ajout d'un lien vers les livres de Patrick Chapin
- Corrections dans le footer


3.0.4 (2021-02-08)
------------------

- Corrections sur l'article sur la méthode de deckbuilding


3.0.3 (2021-02-07)
------------------

- Ajout d'un article sur la méthode de deckbuilding
- Modification de carte "identité" pour certains articles
- Améliorations cosmétiques


3.0.2 (2021-02-03)
------------------

- Amélioration de la génération des decklists
- Amélioration de l'affichage de l'analyse de Winota
- Amélioration de l'affichage des deckslists
- Mise à jour des listes et indication des dates de publication
- Amélioration de l'affichage des titres des articles


3.0.1 (2021-02-02)
------------------

- Modification de carte "identité" pour certains articles
- Modification du ratio d'affichage des decklists


3.0.0 (2021-02-02)
------------------

- Modification de la navigation dans les articles
- Modification de l'apparence des sections
- Remplacement de la bannière
- Mise à jour de la page d'accueil
- Nouvelle apparence
- Suppression de l'affichage au clic
- Ajout de Popper/Tippy pour l'affichage des cartes (1/2)
- Ajout de Popper/Tippy pour l'affichage des cartes (2/2)
- Modification de l'affichage des decklists
- Correction du display des cartes dans les articles
- Correction du display des cartes dans les pages "portfolio"


2.4.1 (2021-02-02)
------------------

- Mise à jour du sitemap
- Ajout d'une présentation de Kelsien


2.4.0 (2021-01-26)
------------------

- Ajout d'une présentation d'Adeliz
- Ajout d'une présentation de Golos


2.3.1 (2021-01-24)
------------------

- Corrections dans la définition des archétypes
- Corrections dans l'analyse d'Isamaru


2.3.0 (2021-01-24)
------------------

- Preloading style and core script for faster rendering
- Preloading decklist rendering
- Fixing hover issue in articles


2.2.0 (2021-01-24)
------------------

- Ajout de trois review sur des decks du Codex
- Fix présentation pour prochaine section
- Ajout d'une review rapide de Isamaru


2.1.0 (2021-01-23)
------------------

- Fix nom de certaines pages
- Correction page "archétypes"
- Fix un lien
- Ajout d'une review rapide de Venser


2.0.12 (2021-01-23)
-------------------

- Fix de la page "Cartes thématiques"
- Retrait de l'image manquante pour zombie33


2.0.11 (2021-01-18)
-------------------

- Ajout disclaimer page Archétypes


2.0.10 (2021-01-17)
-------------------

- Ajout d'une cartouche wip dans section archetype
- Ajout d'une liste de Adeliz, the Cinder Wind
- Ajout d'une liste de Aminatou, the Fateshifter
- Ajout d'une liste de Golos, Tireless Pilgrim
- Ajout d'une liste de The Gitrog Monster
- Ajout d'une liste de Titania, Protector of Argoth


2.0.9 (2021-01-16)
------------------

- Ajout de la page sur les bounces
- Ajout de la page sur les cantrips
- MAJ liste de Winota vers version 5.1
- Ajout de 3 decklistes


2.0.8 (2021-01-07)
------------------

- Fix card display in decklists


2.0.7 (2021-01-07)
------------------

- Upgrade win-o-math calculator
- Ajout présentation rapide de Winota


2.0.6 (2021-01-07)
------------------

- Fix decklist converter
- Fix Winota decklist


2.0.5 (2021-01-07)
------------------

- Update robots.txt


2.0.4 (2021-01-06)
------------------

- Ajout des Win-o-Maths


2.0.3 (2021-01-06)
------------------

- Fix Manifest


2.0.2 (2021-01-06)
------------------

- Fix favicon


2.0.1 (2021-01-06)
------------------

- Fix title index.html


2.0.0 (2021-01-06)
------------------

- Retrait des sets "Secret Lair", "Master" et "Funny"
- Ajout des titres de page différenciés


1.2.7 (2021-01-06)
------------------

- Fixed backend problem (wrong permission on vps folder)
- Back to 1.2.4


1.2.6 (2021-01-06)
------------------

- library.json.gz


1.2.5 (2021-01-06)
------------------

- Send library.json.gz


1.2.4 (2021-01-06)
------------------

- Écriture de la page grosses créatures
- Suppression d'une fonction en doublon dans le backend


1.2.3 (2021-01-04)
------------------

- Ajout robots.txt
- Ajout sitemap.xml
- Ajout d'une méthode pour les servir directement


1.2.2 (2021-01-04)
------------------

- Ajout d'un paragraphe sur les enchants à mana dans ramp
- Ajout d'un paragraphe sur les enchants à mana dans dorks
- Retrait du tip dans l'analyse de Kess
- Ajout d'une balise `<meta name="robots" content="all">` pour le data crawling


1.2.1 (2021-01-04)
------------------

- Corrections de l'outil analytique


1.2.0 (2021-01-04)
------------------

- Ajout outil analytique


1.1.1 (2021-01-04)
------------------

- Espacement entre paragraphes
- Correction de la page "ramp"


1.1.0 (2021-01-04)
------------------

- Correction des couleurs des decklists "light"
- Correction de l'espacement des cartes thématiques
- Changement de l'entrée "la recherche de créatures" par "les mana dorks"
- Rédaction de la page de ramp
- Rédaction de la page de mana dork


1.0.1 (2021-01-03)
------------------

- Fix og_description


1.0.0 (2021-01-03)
------------------

- Site en beta
